@@ -1030,3 +1030,14 @@ pub struct TsConstAssertion {
     #[serde(rename = "expression")]
     pub expr: Box<Expr>,
 }
+
+#[ast_node("TsInstantiation")]
+#[derive(Eq, Hash, EqIgnoreSpan)]
+#[cfg_attr(feature = "arbitrary", derive(arbitrary::Arbitrary))]
+pub struct TsInstantiation {
+    pub span: Span,
+    #[serde(rename = "expression")]
+    pub expr: Box<Expr>,
+    #[serde(rename = "typeArguments")]
+    pub type_args: TsTypeParamInstantiation,
+}
